@@ -248,7 +248,7 @@ class TorchFitter:
                         f'ETA: {(len(train_loader)-step)*(time.time() - t)/(step+1):.2f}', end=''
                     )
             # Calculate batch size
-            batch_size = data[0].shape[0]
+            batch_size = data['x'].shape[0]
 
             # Run one batch
             loss = self.train_one_batch(data)
